==> huaweicloudsdkkafka-3.1.126-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/list_topic_partitions_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTopicPartitionsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'partitions': 'list[KafkaTopicPartitionResponsePartitions]'
    }

    attribute_map = {
        'total': 'total',
        'partitions': 'partitions'
    }

    def __init__(self, total=None, partitions=None):
        """ListTopicPartitionsResponse

        The model defined in huaweicloud sdk

        :param total: 总条数
        :type total: int
        :param partitions: 分区数组
        :type partitions: list[:class:`huaweicloudsdkkafka.v2.KafkaTopicPartitionResponsePartitions`]
        """
        
        super(ListTopicPartitionsResponse, self).__init__()

        self._total = None
        self._partitions = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if partitions is not None:
            self.partitions = partitions

    @property
    def total(self):
        """Gets the total of this ListTopicPartitionsResponse.

        总条数

        :return: The total of this ListTopicPartitionsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListTopicPartitionsResponse.

        总条数

        :param total: The total of this ListTopicPartitionsResponse.
        :type total: int
        """
        self._total = total

    @property
    def partitions(self):
        """Gets the partitions of this ListTopicPartitionsResponse.

        分区数组

        :return: The partitions of this ListTopicPartitionsResponse.
        :rtype: list[:class:`huaweicloudsdkkafka.v2.KafkaTopicPartitionResponsePartitions`]
        """
        return self._partitions

    @partitions.setter
    def partitions(self, partitions):
        """Sets the partitions of this ListTopicPartitionsResponse.

        分区数组

        :param partitions: The partitions of this ListTopicPartitionsResponse.
        :type partitions: list[:class:`huaweicloudsdkkafka.v2.KafkaTopicPartitionResponsePartitions`]
        """
        self._partitions = partitions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTopicPartitionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkafka-3.1.151-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/list_topic_partitions_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListTopicPartitionsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'partitions': 'list[KafkaTopicPartitionResponsePartitions]'
    }

    attribute_map = {
        'total': 'total',
        'partitions': 'partitions'
    }

    def __init__(self, total=None, partitions=None):
        r"""ListTopicPartitionsResponse

        The model defined in huaweicloud sdk

        :param total: 总条数
        :type total: int
        :param partitions: 分区数组
        :type partitions: list[:class:`huaweicloudsdkkafka.v2.KafkaTopicPartitionResponsePartitions`]
        """
        
        super(ListTopicPartitionsResponse, self).__init__()

        self._total = None
        self._partitions = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if partitions is not None:
            self.partitions = partitions

    @property
    def total(self):
        r"""Gets the total of this ListTopicPartitionsResponse.

        总条数

        :return: The total of this ListTopicPartitionsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ListTopicPartitionsResponse.

        总条数

        :param total: The total of this ListTopicPartitionsResponse.
        :type total: int
        """
        self._total = total

    @property
    def partitions(self):
        r"""Gets the partitions of this ListTopicPartitionsResponse.

        分区数组

        :return: The partitions of this ListTopicPartitionsResponse.
        :rtype: list[:class:`huaweicloudsdkkafka.v2.KafkaTopicPartitionResponsePartitions`]
        """
        return self._partitions

    @partitions.setter
    def partitions(self, partitions):
        r"""Sets the partitions of this ListTopicPartitionsResponse.

        分区数组

        :param partitions: The partitions of this ListTopicPartitionsResponse.
        :type partitions: list[:class:`huaweicloudsdkkafka.v2.KafkaTopicPartitionResponsePartitions`]
        """
        self._partitions = partitions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListTopicPartitionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
